@@ -502,6 +502,22 @@ def yamlmod(obj, *paths):
         else:
             yamlsave(obj, *paths)
 
+def yamlpop(key, *paths):
+    '''
+    Pop a key out of a yaml file.
+
+    Args:
+        key (str): Name of the key to remove.
+        *paths: Path to a yaml file. The file must be a map / dictionary.
+
+    Returns:
+        None
+    '''
+    obj = yamlload(*paths)
+    if obj is not None:
+        obj.pop(key, None)
+        yamlsave(obj, *paths)
+
 def verstr(vtup):
     '''
     Convert a version tuple to a string.
@@ -648,8 +664,7 @@ def firethread(f):
     return callmeth
 
 def worker(meth, *args, **kwargs):
-    thr = threading.Thread(target=meth, args=args, kwargs=kwargs)
-    thr.setDaemon(True)
+    thr = threading.Thread(target=meth, args=args, kwargs=kwargs, daemon=True)
     thr.start()
     return thr
 
