@@ -330,6 +330,12 @@ class CertDir:
         '''
         return self._loadCertPath(self.getCaCertPath(name))
 
+    def getCaCertBytes(self, name):
+        path = self.getCaCertPath(name)
+        if os.path.exists(path):
+            with open(path, 'rb') as fd:
+                return fd.read()
+
     def getCaCerts(self):
         '''
         Return a list of CA certs from the CertDir.
@@ -487,6 +493,12 @@ class CertDir:
         '''
         return self._loadCertPath(self.getHostCertPath(name))
 
+    def getHostCertHash(self, name):
+        cert = self.getHostCert(name)
+        if cert is None:
+            return None
+        return cert.digest('SHA256').decode().lower().replace(':', '')
+
     def getHostCertPath(self, name):
         '''
         Gets the path to a host certificate.
@@ -796,7 +808,7 @@ class CertDir:
         cert.set_issuer(cacert.get_subject())
         cert.sign(cakey, self.signing_digest)
 
-    def signHostCsr(self, xcsr, signas, outp=None, sans=None):
+    def signHostCsr(self, xcsr, signas, outp=None, sans=None, save=True):
         '''
         Signs a host CSR with a CA keypair.
 
@@ -816,7 +828,7 @@ class CertDir:
         '''
         pkey = xcsr.get_pubkey()
         name = xcsr.get_subject().CN
-        return self.genHostCert(name, csr=pkey, signas=signas, outp=outp, sans=sans)
+        return self.genHostCert(name, csr=pkey, signas=signas, outp=outp, sans=sans, save=save)
 
     def selfSignCert(self, cert, pkey):
         '''
@@ -837,12 +849,12 @@ class CertDir:
         cert.set_issuer(cert.get_subject())
         cert.sign(pkey, self.signing_digest)
 
-    def signUserCsr(self, xcsr, signas, outp=None):
+    def signUserCsr(self, xcsr, signas, outp=None, save=True):
         '''
         Signs a user CSR with a CA keypair.
 
         Args:
-            cert (OpenSSL.crypto.X509Req): The certificate signing request.
+            xcsr (OpenSSL.crypto.X509Req): The certificate signing request.
             signas (str): The CA keypair name to sign the CSR with.
             outp (synapse.lib.output.Output): The output buffer.
 
@@ -854,7 +866,7 @@ class CertDir:
         '''
         pkey = xcsr.get_pubkey()
         name = xcsr.get_subject().CN
-        return self.genUserCert(name, csr=pkey, signas=signas, outp=outp)
+        return self.genUserCert(name, csr=pkey, signas=signas, outp=outp, save=save)
 
     def _loadCasIntoSSLContext(self, ctx):
 
@@ -974,6 +986,21 @@ class CertDir:
             fd.truncate(0)
             fd.write(crypto.dump_privatekey(crypto.FILETYPE_PEM, pkey))
 
+    def saveCaCertByts(self, byts):
+        cert = self._loadCertByts(byts)
+        name = cert.get_subject().CN
+        return self._saveCertTo(cert, 'cas', f'{name}.crt')
+
+    def saveHostCertByts(self, byts):
+        cert = self._loadCertByts(byts)
+        name = cert.get_subject().CN
+        return self._saveCertTo(cert, 'hosts', f'{name}.crt')
+
+    def saveUserCertByts(self, byts):
+        cert = self._loadCertByts(byts)
+        name = cert.get_subject().CN
+        return self._saveCertTo(cert, 'users', f'{name}.crt')
+
     def _checkDupFile(self, path):
         if os.path.isfile(path):
             raise s_exc.DupFileName(mesg=f'Duplicate file {path}', path=path)
@@ -1039,7 +1066,10 @@ class CertDir:
     def _loadCertPath(self, path):
         byts = self._getPathBytes(path)
         if byts:
-            return crypto.load_certificate(crypto.FILETYPE_PEM, byts)
+            return self._loadCertByts(byts)
+
+    def _loadCertByts(self, byts):
+        return crypto.load_certificate(crypto.FILETYPE_PEM, byts)
 
     def _loadCsrPath(self, path):
         byts = self._getPathBytes(path)
