@@ -8,6 +8,7 @@ import yaml
 import fastjsonschema
 
 import synapse.exc as s_exc
+import synapse.common as s_common
 
 import synapse.lib.hashitem as s_hashitem
 
@@ -111,8 +112,8 @@ class Config(c_abc.MutableMapping):
         schema (dict): The JSON Schema (draft v7) which to validate
                        configuration data against.
         conf (dict): Optional, a set of configuration data to preload.
-        envar_prefix (str): Optional, a prefix used when collecting configuration
-                            data from environment variables.
+        envar_prefixes (list): Optional, a list of prefix strings used when collecting
+                               configuration data from environment variables.
 
     Notes:
         This class implements the collections.abc.MutableMapping class, so it
@@ -128,19 +129,33 @@ class Config(c_abc.MutableMapping):
     def __init__(self,
                  schema,
                  conf=None,
-                 envar_prefix=None,
+                 envar_prefixes=None,
                  ):
         self.json_schema = schema
         if conf is None:
             conf = {}
-        self.conf = conf
+        if envar_prefixes is None:
+            envar_prefixes = ('', )
+        self.conf = {}
         self._argparse_conf_names = {}
         self._argparse_conf_parsed_names = {}
-        self.envar_prefix = envar_prefix
+        self.envar_prefixes = envar_prefixes
         self.validator = getJsValidator(self.json_schema)
+        self._prop_schemas = {}
+        self._prop_validators = {}
+        for k, v in self.json_schema.get('properties').items():
+            prop_schema = {
+                '$schema': 'http://json-schema.org/draft-07/schema#',
+            }
+            prop_schema.update(v)
+            self._prop_schemas[k] = prop_schema
+            self._prop_validators[k] = getJsValidator(prop_schema)
+        # Copy the data in so that it is validated.
+        for k, v in conf.items():
+            self[k] = v
 
     @classmethod
-    def getConfFromCell(cls, cell, conf=None, envar_prefix=None):
+    def getConfFromCell(cls, cell, conf=None, envar_prefixes=None):
         '''
         Get a Config object from a Cell directly (either the ctor or the instance thereof).
 
@@ -148,7 +163,9 @@ class Config(c_abc.MutableMapping):
             Config: A Config object.
         '''
         schema = getJsSchema(cell.confbase, cell.confdefs)
-        return cls(schema, conf=conf, envar_prefix=envar_prefix)
+        if envar_prefixes is None:
+            envar_prefixes = cell.getEnvPrefix()
+        return cls(schema, conf=conf, envar_prefixes=envar_prefixes)
 
     def getArgParseArgs(self):
 
@@ -223,6 +240,17 @@ class Config(c_abc.MutableMapping):
                 continue
             self.setdefault(nname, v)
 
+    def setConfFromFile(self, path):
+        '''
+        Set the opts for a conf object from YAML file path.
+        '''
+        item = s_common.yamlload(path)
+        if item is None:
+            return
+
+        for name, valu in item.items():
+            self.setdefault(name, valu)
+
     # Envar support methods
     def setConfFromEnvs(self):
         '''
@@ -247,30 +275,43 @@ class Config(c_abc.MutableMapping):
             With the prefix ``cortex``, the the environment variable is resolved as ``CORTEX_AUTH_PASSWD``.
 
         Returns:
-            None: Returns None.
+            dict: Returns a dictionary of values which were set from enviroment variables.
         '''
-        name2envar = self.getEnvarMapping()
-        for name, envar in name2envar.items():
-            envv = os.getenv(envar)
-            if envv is not None:
-                envv = yaml.safe_load(envv)
-                resp = self.setdefault(name, envv)
-                if resp == envv:
-                    logger.debug(f'Set config valu from envar: [{envar}]')
+        updates = {}
+        for prefix in self.envar_prefixes:
+            name2envar = self.getEnvarMapping(prefix=prefix)
+            for name, envar in name2envar.items():
+                envv = os.getenv(envar)
+                if envv is not None:
+                    envv = yaml.safe_load(envv)
 
-    def getEnvarMapping(self):
+                    curv = self.get(name, s_common.novalu)
+                    if curv is not s_common.novalu:
+                        if curv != envv:
+                            logger.warning(f'Config from envar [{envar}] skipped due to already being set!')
+                        continue
+
+                    self.setdefault(name, envv)
+                    logger.debug(f'Set config valu from envar: [{envar}]')
+                    updates[name] = envv
+
+        return updates
+
+    def getEnvarMapping(self, prefix=None):
         '''
         Get a mapping of config values to envars.
 
         Configuration values which have the ``hideconf`` value set to True are not resolved from environment
         variables.
         '''
+        if prefix is None:
+            prefix = self.envar_prefixes[0]
         ret = {}
         for name, conf in self.json_schema.get('properties', {}).items():
             if conf.get('hideconf'):
                 continue
 
-            envar = make_envar_name(name, prefix=self.envar_prefix)
+            envar = make_envar_name(name, prefix=prefix)
             ret[name] = envar
         return ret
 
@@ -317,6 +358,30 @@ class Config(c_abc.MutableMapping):
 
         return self.conf.get(key)
 
+    def reqKeyValid(self, key, value):
+        '''
+        Test if a key is valid for the provided schema it is associated with.
+
+        Args:
+            key (str): Key to check.
+            value: Value to check.
+
+        Raises:
+            BadArg: If the key has no associated schema.
+            BadConfValu: If the data is not schema valid.
+
+        Returns:
+            None when valid.
+        '''
+        validator = self._prop_validators.get(key)
+        if validator is None:
+            raise s_exc.BadArg(mesg=f'Key {key} is not a valid config', )
+        try:
+            validator(value)
+        except s_exc.SchemaViolation as e:
+            raise s_exc.BadConfValu(mesg=f'Invalid config for {key}, {e.get("mesg")}', name=key, value=value) from None
+        return
+
     def asDict(self):
         '''
         Get a copy of configuration data.
@@ -344,11 +409,7 @@ class Config(c_abc.MutableMapping):
         return self.conf.__delitem__(key)
 
     def __setitem__(self, key, value):
-        # This explicitly doesn't do any type validation.
-        # The type validation is done on-demand, in order to
-        # allow a user to incrementally construct the config
-        # from different sources before turning around and
-        # doing a validation pass which may fail.
+        self.reqKeyValid(key, value)
         return self.conf.__setitem__(key, value)
 
     def __getitem__(self, item):
