@@ -706,6 +706,24 @@ class HiveRole(HiveRuler):
             info = self.authgates[gateiden] = await gate.genRoleInfo(self.iden)
         return info
 
+    def allowed(self, perm, default=None, gateiden=None):
+
+        perm = tuple(perm)
+        if gateiden is not None:
+            info = self.authgates.get(gateiden)
+            if info is not None:
+                for allow, path in info.get('rules', ()):
+                    if perm[:len(path)] == path:
+                        return allow
+            return default
+
+        # 2. check user rules
+        for allow, path in self.info.get('rules', ()):
+            if perm[:len(path)] == path:
+                return allow
+
+        return default
+
 class HiveUser(HiveRuler):
     '''
     A user (could be human or computer) of the system within HiveAuth.
@@ -759,6 +777,10 @@ class HiveUser(HiveRuler):
     async def setName(self, name):
         return await self.auth.setUserName(self.iden, name)
 
+    async def allow(self, perm):
+        if not self.allowed(perm):
+            await self.addRule((True, perm), indx=0)
+
     def allowed(self, perm, default=None, gateiden=None):
         perm = tuple(perm)
         return self.permcache.get((perm, default, gateiden))
