@@ -664,7 +664,7 @@ class Snap(s_base.Base):
             await asyncio.sleep(0)
             return node
 
-        layrs = (layr for layr in self.layers if layr.iden not in cache)
+        layrs = [layr for layr in self.layers if layr.iden not in cache]
         if layrs:
             indx = 0
             newsodes = await self.core._getStorNodes(buid, layrs)
@@ -933,7 +933,17 @@ class Snap(s_base.Base):
         return nodes
 
     async def saveNodeEdits(self, edits, meta):
-        saveoff, changes, nodes = await self._applyNodeEdits(edits, meta)
+        if meta is None:
+            meta = await self.getSnapMeta()
+
+        saveoff = -1
+        changes = []
+
+        for edit in edits:
+            await self.getNodeByBuid(edit[0])
+            saveoff, changes_, _ = await self._applyNodeEdits((edit,), meta)
+            changes.extend(changes_)
+
         return saveoff, changes
 
     async def _applyNodeEdits(self, edits, meta):
