@@ -1,6 +1,7 @@
 import json
 import asyncio
 import logging
+import urllib.parse
 
 logger = logging.getLogger(__name__)
 
@@ -187,9 +188,43 @@ class LibHttp(s_stormtypes.Lib):
                       {'name': 'ssl_verify', 'type': 'boolean', 'desc': 'Perform SSL/TLS verification.',
                        'default': True, },
                       {'name': 'timeout', 'type': 'int', 'desc': 'Total timeout for the request in seconds.',
-                       'default': 300, }
+                       'default': 300, },
+                      {'name': 'params', 'type': 'dict', 'desc': 'Optional parameters which may be passed to the connection request.',
+                       'default': None, },
                   ),
                   'returns': {'type': 'storm:http:socket', 'desc': 'A websocket object.'}}},
+        {'name': 'urlencode', 'desc': '''
+            Urlencode a text string.
+
+            This will replace special characters in a string using the %xx escape and
+            replace spaces with plus signs.
+
+            Examples:
+                Urlencode a string::
+
+                    $str=$lib.inet.http.urlencode("http://go ogle.com")
+         ''',
+         'type': {'type': 'function', '_funcname': 'urlencode',
+                  'args': (
+                      {'name': 'text', 'type': 'str', 'desc': 'The text string.', },
+                  ),
+                  'returns': {'type': 'str', 'desc': 'The urlencoded string.', }}},
+        {'name': 'urldecode', 'desc': '''
+            Urldecode a text string.
+
+            This will replace %xx escape characters with the special characters they represent
+            and replace plus signs with spaces.
+
+            Examples:
+                Urlencode a string::
+
+                    $str=$lib.inet.http.urldecode("http%3A%2F%2Fgo+ogle.com")
+         ''',
+         'type': {'type': 'function', '_funcname': 'urldecode',
+                  'args': (
+                      {'name': 'text', 'type': 'str', 'desc': 'The text string.', },
+                  ),
+                  'returns': {'type': 'str', 'desc': 'The urldecoded string.', }}},
     )
     _storm_lib_path = ('inet', 'http')
 
@@ -200,6 +235,8 @@ class LibHttp(s_stormtypes.Lib):
             'head': self._httpEasyHead,
             'request': self._httpRequest,
             'connect': self.inetHttpConnect,
+            'urlencode': self.urlencode,
+            'urldecode': self.urldecode,
         }
 
     def strify(self, item):
@@ -209,6 +246,14 @@ class LibHttp(s_stormtypes.Lib):
             return {str(k): str(v) for k, v in item.items()}
         return item
 
+    async def urlencode(self, text):
+        text = await s_stormtypes.tostr(text)
+        return urllib.parse.quote_plus(text)
+
+    async def urldecode(self, text):
+        text = await s_stormtypes.tostr(text)
+        return urllib.parse.unquote_plus(text)
+
     async def _httpEasyHead(self, url, headers=None, ssl_verify=True, params=None, timeout=300,
                             allow_redirects=False):
         return await self._httpRequest('HEAD', url, headers=headers, ssl_verify=ssl_verify, params=params,
@@ -225,11 +270,12 @@ class LibHttp(s_stormtypes.Lib):
                                        ssl_verify=ssl_verify, params=params, timeout=timeout,
                                        allow_redirects=allow_redirects, fields=fields, )
 
-    async def inetHttpConnect(self, url, headers=None, ssl_verify=True, timeout=300):
+    async def inetHttpConnect(self, url, headers=None, ssl_verify=True, timeout=300, params=None):
 
         url = await s_stormtypes.tostr(url)
         headers = await s_stormtypes.toprim(headers)
         timeout = await s_stormtypes.toint(timeout, noneok=True)
+        params = await s_stormtypes.toprim(params)
 
         headers = self.strify(headers)
 
@@ -244,7 +290,8 @@ class LibHttp(s_stormtypes.Lib):
 
         try:
             sess = await sock.enter_context(aiohttp.ClientSession(connector=connector, timeout=timeout))
-            sock.resp = await sock.enter_context(sess.ws_connect(url, headers=headers, ssl=ssl_verify, timeout=timeout))
+            sock.resp = await sock.enter_context(sess.ws_connect(url, headers=headers, ssl=ssl_verify, timeout=timeout,
+                                                                 params=params, ))
 
             sock._syn_refs = 0
             self.runt.onfini(sock)
