@@ -10,6 +10,7 @@ import synapse.common as s_common
 import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.snap as s_snap
+import synapse.lib.layer as s_layer
 import synapse.lib.nexus as s_nexus
 import synapse.lib.config as s_config
 import synapse.lib.scrape as s_scrape
@@ -45,7 +46,7 @@ class ViewApi(s_cell.CellApi):
         await s_cell.CellApi.__anit__(self, core, link, user)
         self.view = view
         layriden = view.layers[0].iden
-        self.allowedits = user.allowed(('node'), gateiden=layriden)
+        self.allowedits = user.allowed(('node',), gateiden=layriden)
 
     async def storNodeEdits(self, edits, meta):
 
@@ -716,7 +717,24 @@ class View(s_nexus.Pusher):  # type: ignore
             async for nodeedits in fromlayr.iterLayerNodeEdits():
                 await self.parent.storNodeEdits([nodeedits], meta)
 
-        await fromlayr.truncate()
+    async def wipeLayer(self, useriden=None):
+        '''
+        Delete the data in the write layer by generating del nodeedits.
+        Triggers will be run.
+        '''
+
+        if useriden is None:
+            user = await self.core.auth.getUserByName('root')
+        else:
+            user = await self.core.auth.reqUser(useriden)
+
+        await self.wipeAllowed(user)
+
+        async with await self.snap(user=user) as snap:
+            meta = await snap.getSnapMeta()
+            async for nodeedit in self.layers[0].iterWipeNodeEdits():
+                await snap.getNodeByBuid(nodeedit[0])  # to load into livenodes for callbacks
+                await snap.saveNodeEdits([nodeedit], meta)
 
     def _confirm(self, user, perms):
         layriden = self.layers[0].iden
@@ -789,6 +807,18 @@ class View(s_nexus.Pusher):  # type: ignore
                     if splicecount % 1000 == 0:
                         await asyncio.sleep(0)
 
+    async def wipeAllowed(self, user=None):
+        '''
+        Check whether a user can wipe the write layer in the current view.
+        '''
+        if user is None or user.isAdmin():
+            return
+
+        async for nodeedit in self.layers[0].iterWipeNodeEdits():
+            for offs, perm in s_layer.getNodeEditPerms([nodeedit]):
+                self._confirm(user, perm)
+                await asyncio.sleep(0)
+
     async def runTagAdd(self, node, tag, valu, view=None):
 
         # Run the non-glob callbacks, then the glob callbacks
@@ -956,7 +986,7 @@ class View(s_nexus.Pusher):  # type: ignore
         user = await self.core.auth.reqUser(meta.get('user'))
         async with await self.snap(user=user) as snap:
             # go with the anti-pattern for now...
-            await snap.applyNodeEdits(edits)
+            await snap.saveNodeEdits(edits, None)
 
     async def storNodeEdits(self, edits, meta):
         return await self.addNodeEdits(edits, meta)
