@@ -35,6 +35,12 @@ class BaseModule(s_module.CoreModule):
                     'interfaces': ('taxonomy',),
                     'doc': 'A taxonomy of event types for meta:event nodes.'}),
 
+                ('meta:ruleset', ('guid', {}), {
+                    'doc': 'A set of rules linked with -(has)> edges.'}),
+
+                ('meta:rule', ('guid', {}), {
+                    'doc': 'A generic rule linked to matches with -(matches)> edges.'}),
+
                 ('graph:cluster', ('guid', {}), {
                     'doc': 'A generic node, used in conjunction with Edge types, to cluster arbitrary nodes to a '
                            'single node in the model.'}),
@@ -123,6 +129,37 @@ class BaseModule(s_module.CoreModule):
 
                 ('meta:event:taxonomy', {}, ()),
 
+                ('meta:ruleset', {}, (
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
+                        'doc': 'A name for the ruleset.'}),
+                    ('desc', ('str', {}), {
+                        'disp': {'hint': 'text'},
+                        'doc': 'A description of the ruleset.'}),
+                    ('author', ('ps:contact', {}), {
+                        'doc': 'The contact information of the ruleset author.'}),
+                    ('created', ('time', {}), {
+                        'doc': 'The time the ruleset was initially created.'}),
+                    ('updated', ('time', {}), {
+                        'doc': 'The time the ruleset was most recently modified.'}),
+                )),
+
+                ('meta:rule', {}, (
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
+                        'doc': 'A name for the rule.'}),
+                    ('desc', ('str', {}), {
+                        'disp': {'hint': 'text'},
+                        'doc': 'A description of the rule.'}),
+                    ('text', ('str', {}), {
+                        'disp': {'hint': 'text'},
+                        'doc': 'The text of the rule logic.'}),
+                    ('author', ('ps:contact', {}), {
+                        'doc': 'The contact information of the rule author.'}),
+                    ('created', ('time', {}), {
+                        'doc': 'The time the rule was initially created.'}),
+                    ('updated', ('time', {}), {
+                        'doc': 'The time the rule was most recently modified.'}),
+                )),
+
                 ('graph:cluster', {}, (
                     ('name', ('str', {'lower': True}), {
                         'doc': 'A human friendly name for the cluster.'}),
