@@ -210,7 +210,6 @@ class ItModule(s_module.CoreModule):
         self.model.form('it:dev:regkey').onAdd(self._onFormMakeDevStr)
         self.model.prop('it:prod:softver:arch').onSet(self._onPropSoftverArch)
         self.model.prop('it:prod:softver:vers').onSet(self._onPropSoftverVers)
-        self.model.prop('it:prod:softver:software').onSet(self._onPropSoftverSoft)
 
     def bruteVersionStr(self, valu):
         '''
@@ -249,17 +248,6 @@ class ItModule(s_module.CoreModule):
         pprop = node.ndef[1]
         await node.snap.addNode('it:dev:str', pprop)
 
-    async def _onPropSoftverSoft(self, node, oldv):
-        # Check to see if name is available and set it if possible
-        prop = node.get('software')
-        if prop:
-            opts = {'vars': {'soft': prop}}
-            nodes = await node.snap.nodes('it:prod:soft=$soft', opts=opts)
-            if nodes:
-                name = nodes[0].get('name')
-                if name:
-                    await node.set('software:name', name)
-
     async def _onPropSoftverArch(self, node, oldv):
         # make it:dev:str for arch
         prop = node.get('arch')
@@ -387,7 +375,10 @@ class ItModule(s_module.CoreModule):
                     'doc': 'A Windows registry key/value pair.',
                 }),
                 ('it:prod:soft', ('guid', {}), {
-                    'doc': 'A arbitrary, unversioned software product.',
+                    'doc': 'A software product.',
+                }),
+                ('it:prod:softname', ('str', {'onespace': True, 'lower': True}), {
+                    'doc': 'A software product name.',
                 }),
                 ('it:prod:hardware', ('guid', {}), {
                     'doc': 'A specification for a piece of IT hardware.',
@@ -548,6 +539,8 @@ class ItModule(s_module.CoreModule):
                 ('it:reveng:impfunc', ('str', {'lower': 1}), {
                     'doc': 'A function from an imported library.',
                 }),
+                ('it:sec:c2:config', ('guid', {}), {
+                    'doc': 'An extracted C2 config from an executable.'}),
             ),
 
             'interfaces': (
@@ -563,6 +556,8 @@ class ItModule(s_module.CoreModule):
                             'doc': 'The host on which the activity occurred.'}),
                         ('time', ('time', {}), {
                             'doc': 'The time that the activity started.'}),
+                        ('sandbox:file', ('file:bytes', {}), {
+                            'doc': 'The initial sample given to a sandbox environment to analyze.'}),
                     ),
                 }),
             ),
@@ -595,6 +590,9 @@ class ItModule(s_module.CoreModule):
                     ('os', ('it:prod:softver', {}), {
                         'doc': 'The operating system of the host.'
                     }),
+                    ('os:name', ('it:prod:softname', {}), {
+                        'doc': 'A software product name for the host operating system. Used for entity resolution.',
+                    }),
                     ('hardware', ('it:prod:hardware', {}), {
                         'doc': 'The hardware specification for this host.',
                     }),
@@ -927,10 +925,10 @@ class ItModule(s_module.CoreModule):
                     ('software', ('it:prod:soft', {}), {
                         'doc': 'Used to map an ATT&CK software to a synapse it:prod:soft.',
                     }),
-                    ('name', ('str', {'strip': True}), {
+                    ('name', ('it:prod:softname', {}), {
                         'doc': 'The primary name for the ATT&CK software.',
                     }),
-                    ('names', ('array', {'type': 'str', 'uniq': True, 'sorted': True}), {
+                    ('names', ('array', {'type': 'it:prod:softname', 'uniq': True, 'sorted': True}), {
                         'doc': 'Associated names for the ATT&CK software.',
                     }),
                     ('desc', ('str', {'strip': True}), {
@@ -1025,10 +1023,10 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The it:host which has this component installed.'}),
                 )),
                 ('it:prod:soft', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True}), {
+                    ('name', ('it:prod:softname', {}), {
                         'doc': 'Name of the software.',
                     }),
-                    ('names', ('array', {'type': 'it:dev:str', 'uniq': True, 'sorted': True}), {
+                    ('names', ('array', {'type': 'it:prod:softname', 'uniq': True, 'sorted': True}), {
                         'doc': 'Observed/variant names for this software.',
                     }),
                     ('desc', ('str', {}), {
@@ -1072,6 +1070,8 @@ class ItModule(s_module.CoreModule):
                         'doc': 'Set to True if the software is a library.'}),
                 )),
 
+                ('it:prod:softname', {}, ()),
+
                 ('it:adid', {}, ()),
                 ('it:os:ios:idfa', {}, ()),
                 ('it:os:android:aaid', {}, ()),
@@ -1121,12 +1121,13 @@ class ItModule(s_module.CoreModule):
                         'doc': 'Software associated with this version instance.',
                     }),
                     ('software:name', ('str', {'lower': True, 'strip': True}), {
-                        'doc': 'The name of the software at a particular version.',
+                        'deprecated': True,
+                        'doc': 'Deprecated. Please use it:prod:softver:name.',
                     }),
-                    ('name', ('it:dev:str', {}), {
-                        'doc': 'Name of the software.',
+                    ('name', ('it:prod:softname', {}), {
+                        'doc': 'Name of the software version.',
                     }),
-                    ('names', ('array', {'type': 'it:dev:str', 'uniq': True, 'sorted': True}), {
+                    ('names', ('array', {'type': 'it:prod:softname', 'uniq': True, 'sorted': True}), {
                         'doc': 'Observed/variant names for this software version.',
                     }),
                     ('desc', ('str', {}), {
@@ -1319,6 +1320,9 @@ class ItModule(s_module.CoreModule):
                     ('killedby', ('it:exec:proc', {}), {
                         'doc': 'The process which killed this process.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:thread', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1339,6 +1343,9 @@ class ItModule(s_module.CoreModule):
                     ('src:thread', ('it:exec:thread', {}), {
                         'doc': 'The thread which created this thread.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:loadlib', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1359,6 +1366,9 @@ class ItModule(s_module.CoreModule):
                     ('file', ('file:bytes', {}), {
                         'doc': 'The library file that was loaded.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:mmap', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1391,6 +1401,9 @@ class ItModule(s_module.CoreModule):
                     ('hash:sha256', ('hash:sha256', {}), {
                         'doc': 'A SHA256 hash of the memory map. Bytes may optionally be present in the axon.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:mutex', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1408,6 +1421,9 @@ class ItModule(s_module.CoreModule):
                     ('name', ('it:dev:mutex', {}), {
                         'doc': 'The mutex string.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:pipe', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1425,6 +1441,9 @@ class ItModule(s_module.CoreModule):
                     ('name', ('it:dev:pipe', {}), {
                         'doc': 'The named pipe string.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:url', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1469,6 +1488,9 @@ class ItModule(s_module.CoreModule):
                     ('client:port', ('inet:port', {}), {
                         'doc': 'The client port during the URL retrieval..'
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:bind', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1495,6 +1517,9 @@ class ItModule(s_module.CoreModule):
                     ('server:port', ('inet:port', {}), {
                         'doc': 'The bound (listening) TCP port.'
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:fs:file', {}, (
                     ('host', ('it:host', {}), {
@@ -1564,6 +1589,9 @@ class ItModule(s_module.CoreModule):
                     ('file', ('file:bytes', {}), {
                         'doc': 'The file that was created.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:file:del', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1595,6 +1623,9 @@ class ItModule(s_module.CoreModule):
                     ('file', ('file:bytes', {}), {
                         'doc': 'The file that was deleted.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:file:read', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1626,6 +1657,9 @@ class ItModule(s_module.CoreModule):
                     ('file', ('file:bytes', {}), {
                         'doc': 'The file that was read.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:file:write', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1657,6 +1691,9 @@ class ItModule(s_module.CoreModule):
                     ('file', ('file:bytes', {}), {
                         'doc': 'The file that was modified.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:reg:get', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1674,6 +1711,9 @@ class ItModule(s_module.CoreModule):
                     ('reg', ('it:dev:regval', {}), {
                         'doc': 'The registry key or value that was read.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:reg:set', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1691,6 +1731,9 @@ class ItModule(s_module.CoreModule):
                     ('reg', ('it:dev:regval', {}), {
                         'doc': 'The registry key or value that was written to.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
                 ('it:exec:reg:del', {}, (
                     ('proc', ('it:exec:proc', {}), {
@@ -1708,6 +1751,9 @@ class ItModule(s_module.CoreModule):
                     ('reg', ('it:dev:regval', {}), {
                         'doc': 'The registry key or value that was deleted.',
                     }),
+                    ('sandbox:file', ('file:bytes', {}), {
+                        'doc': 'The initial sample given to a sandbox environment to analyze.'
+                    }),
                 )),
 
                 ('it:app:snort:rule', {}, (
@@ -1767,6 +1813,8 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The time the YARA rule was most recently modified.'}),
                     ('enabled', ('bool', {}), {
                         'doc': 'The rule enabled status to be used for YARA evaluation engines.'}),
+                    ('family', ('it:prod:softname', {}), {
+                        'doc': 'The name of the software family the rule is designed to detect.'}),
                 )),
 
                 ('it:app:yara:match', {}, (
@@ -1833,6 +1881,26 @@ class ItModule(s_module.CoreModule):
 
                 ('it:reveng:impfunc', {}, ()),
 
+                ('it:sec:c2:config', {}, (
+                    ('family', ('it:prod:softname', {}), {
+                        'doc': 'The name of the software family which uses the config.'}),
+                    ('file', ('file:bytes', {}), {
+                        'doc': 'The file that the C2 config was extracted from.'}),
+                    ('servers', ('array', {'type': 'inet:url'}), {
+                        'doc': 'An array of connection URLs built from host/port/passwd combinations.'}),
+                    ('mutex', ('it:dev:mutex', {}), {
+                        'doc': 'The mutex that the software uses to prevent multiple-installations.'}),
+                    ('campaigncode', ('it:dev:str', {}), {
+                        'doc': 'The operator selected string used to identify the campaign or group of targets.'}),
+                    ('crypto:key', ('crypto:key', {}), {
+                        'doc': 'Static key material used to encrypt C2 communications.'}),
+                    ('connect:delay', ('duration', {}), {
+                        'doc': 'The time delay from first execution to connecting to the C2 server.'}),
+                    ('connect:interval', ('duration', {}), {
+                        'doc': 'The configured duration to sleep between connections to the C2 server.'}),
+                    ('raw', ('data', {}), {
+                        'doc': 'A JSON blob containing the raw config extracted from the binary.'}),
+                )),
             ),
         }
         name = 'it'
