@@ -373,6 +373,7 @@ class CellTest(s_t_utils.SynTest):
                 self.true(await proxy.isUserAllowed(visi.iden, ('foo', 'bar')))
                 self.false(await proxy.isUserAllowed(visi.iden, ('hehe', 'haha')))
                 self.false(await proxy.isUserAllowed('newpnewp', ('hehe', 'haha')))
+                self.false(await proxy.isRoleAllowed('newpnewp', ('foo', 'bar')))
 
                 await proxy.setUserProfInfo(visi.iden, 'hehe', 'haha')
                 self.eq('haha', await proxy.getUserProfInfo(visi.iden, 'hehe'))
@@ -864,16 +865,38 @@ class CellTest(s_t_utils.SynTest):
                 self.isin(f'...cell API (telepath): cell://root@{dirn}:*', buf)
                 self.isin('...cell API (https): disabled', buf)
 
+    async def test_cell_initargv_conf(self):
+        async with self.withSetLoggingMock():
+            # Ensure that envars are persisted into the cell config
+            with self.setTstEnvars(SYN_CELL_NEXSLOG_EN='true'):
+                with self.getTestDir() as dirn:
+                    async with await s_cell.Cell.initFromArgv([dirn]) as cell:
+                        self.true(cell.conf.reqConfValu('nexslog:en'))
+                    obj = s_common.yamlload(dirn, 'cell.yaml')
+                    self.eq(obj, {'nexslog:en': True, })
+
     async def test_initargv_failure(self):
         if not os.path.exists('/dev/null'):
             self.skip('Test requires /dev/null to exist.')
 
-        with self.getAsyncLoggerStream('synapse.lib.cell',
-                                       'Error starting cell at /dev/null') as stream:
-            with self.raises(FileExistsError):
-                async with await s_cell.Cell.initFromArgv(['/dev/null']):
-                    pass
-            self.true(await stream.wait(timeout=6))
+        async with self.withSetLoggingMock():
+            with self.getAsyncLoggerStream('synapse.lib.cell',
+                                           'Error starting cell at /dev/null') as stream:
+                with self.raises(FileExistsError):
+                    async with await s_cell.Cell.initFromArgv(['/dev/null']):
+                        pass
+                self.true(await stream.wait(timeout=6))
+
+            # Bad configs can also cause a failure.
+            with self.getTestDir() as dirn:
+                with self.getAsyncLoggerStream('synapse.lib.cell',
+                                               'Error while bootstrapping cell config') as stream:
+                    with self.raises(s_exc.BadConfValu) as cm:
+                        with self.setTstEnvars(SYN_CELL_AUTH_PASSWD="true"):  # interpreted as a yaml bool true
+                            async with await s_cell.Cell.initFromArgv([dirn, ]):
+                                pass
+                    self.eq(cm.exception.get('name'), 'auth:passwd')
+                self.true(await stream.wait(timeout=6))
 
     async def test_cell_backup(self):
 
@@ -996,6 +1019,7 @@ class CellTest(s_t_utils.SynTest):
                 cryo.certdir.genCaCert('localca')
                 cryo.certdir.genHostCert('localhost', signas='localca')
                 cryo.certdir.genUserCert('root@localhost', signas='localca')
+                cryo.certdir.genUserCert('newp@localhost', signas='localca')
 
                 root = await cryo.auth.addUser('root@localhost')
                 await root.setAdmin(True)
@@ -1005,13 +1029,19 @@ class CellTest(s_t_utils.SynTest):
                 addr, port = await cryo.dmon.listen('ssl://0.0.0.0:0?hostname=localhost&ca=localca')
 
                 async with await s_telepath.openurl(f'ssl://root@127.0.0.1:{port}?hostname=localhost') as proxy:
-                    self.nn(await proxy.getCellIden())
+                    self.eq(cryo.iden, await proxy.getCellIden())
 
                 with self.raises(s_exc.BadCertHost):
                     url = f'ssl://root@127.0.0.1:{port}?hostname=borked.localhost'
                     async with await s_telepath.openurl(url) as proxy:
                         pass
 
+                with self.raises(s_exc.NoSuchUser) as cm:
+                    url = f'ssl://newp@127.0.0.1:{port}?hostname=localhost'
+                    async with await s_telepath.openurl(url) as proxy:
+                        pass
+                self.eq(cm.exception.get('user'), 'newp@localhost')
+
     async def test_cell_auth_ctor(self):
         conf = {
             'auth:ctor': 'synapse.tests.test_lib_cell.altAuthCtor',
@@ -1449,3 +1479,32 @@ class CellTest(s_t_utils.SynTest):
 
             foonest = s_common.genpath(core.dirn, 'backups', 'bar', 'backups')
             self.false(os.path.isdir(foonest))
+
+    async def test_mirror_badiden(self):
+        with self.getTestDir() as dirn:
+
+            path00 = s_common.gendir(dirn, 'cell00')
+            path01 = s_common.gendir(dirn, 'coll01')
+
+            conf00 = {'dmon:listen': 'tcp://127.0.0.1:0/',
+                      'https:port': 0,
+                      'nexslog:en': True,
+                      }
+            async with await s_cell.Cell.anit(conf=conf00, dirn=path00) as cell00:
+
+                conf01 = {'dmon:listen': 'tcp://127.0.0.1:0/',
+                          'https:port': 0,
+                          'mirror': cell00.getLocalUrl(),
+                          'nexslog:en': True,
+                          }
+
+                # Create the bad cell with its own guid
+                async with await s_cell.Cell.anit(dirn=path01, conf={'nexslog:en': True,
+                                                               }) as cell01:
+                    pass
+
+                with self.getAsyncLoggerStream('synapse.lib.nexus',
+                                               'has different iden') as stream:
+                    async with await s_cell.Cell.anit(conf=conf01, dirn=path01) as cell01:
+                        await stream.wait(timeout=2)
+                        self.true(await cell01.waitfini(6))
