@@ -43,10 +43,14 @@ class ChopTest(s_t_utils.SynTest):
             (' asdf  asdf    asdf \t \t asdf asdf   ', 'asdf asdf asdf asdf asdf'),
             (' ', ''),
             ('foo   bar baz', 'foo bar baz'),
+            ('\t \t asdf   asdf   ', 'asdf asdf'),
+            ('\n\t asdf  \n asdf   ', 'asdf asdf'),
         ]
         for iv, ev in tvs:
             rv = s_chop.onespace(iv)
             self.eq(rv, ev)
+            # No leading space is left after onespace is applied
+            self.eq(ev, ev.lstrip())
 
     def test_chop_printables(self):
         tvs = [
@@ -81,3 +85,9 @@ class ChopTest(s_t_utils.SynTest):
         self.raises(s_exc.BadTag, s_chop.validateTagMatch, 'foo..bar')
         self.none(s_chop.validateTagMatch('foo.*.bar'))
         self.none(s_chop.validateTagMatch('**foo.*.bar'))
+
+    def test_chop_dashes(self):
+        self.eq('a-b-c-d--e',
+                s_chop.replaceUnicodeDashes('a\u2011b\u2012c\u2013d-\u2014e'))
+        self.eq('a-b-c', s_chop.replaceUnicodeDashes('a-b-c'))
+        self.eq('asdf', s_chop.replaceUnicodeDashes('asdf'))
