@@ -292,9 +292,13 @@ class TypesTest(s_t_utils.SynTest):
 
         # test ranges
         self.nn(t.norm(-2**63))
-        self.raises(s_exc.BadTypeValu, t.norm, (-2**63) - 1)
+        with self.raises(s_exc.BadTypeValu) as cm:
+            t.norm((-2**63) - 1)
+        self.isinstance(cm.exception.get('valu'), str)
         self.nn(t.norm(2**63 - 1))
-        self.raises(s_exc.BadTypeValu, t.norm, 2**63)
+        with self.raises(s_exc.BadTypeValu) as cm:
+            t.norm(2**63)
+        self.isinstance(cm.exception.get('valu'), str)
 
         # test base types that Model snaps in...
         self.eq(t.norm('100')[0], 100)
@@ -1325,3 +1329,22 @@ class TypesTest(s_t_utils.SynTest):
 
             nodes = await core.nodes('test:witharray:fqdns*[~=ehe]')
             self.len(1, nodes)
+
+            await core.addFormProp('test:int', '_hehe', ('array', {'type': 'str'}), {})
+
+            baz = 'baz' * 100
+
+            nodes = await core.nodes(f'[ test:int=1 :_hehe=("foo", "bar", "{baz}") ]')
+            self.len(1, nodes)
+            self.len(1, await core.nodes('test:int:_hehe*[~=foo]'))
+            self.len(1, await core.nodes('test:int:_hehe*[~=baz]'))
+
+            nodes = await core.nodes(f'[ test:int=2 :_hehe=("foo", "bar", "{baz}") ]')
+            self.len(1, nodes)
+            self.len(2, await core.nodes('test:int:_hehe*[~=foo]'))
+            self.len(2, await core.nodes('test:int:_hehe*[~=baz]'))
+
+            buid = nodes[0].buid
+
+            core.getLayer()._testAddPropArrayIndx(buid, 'test:int', '_hehe', ('newp' * 100,))
+            self.len(0, await core.nodes('test:int:_hehe*[~=newp]'))
