@@ -271,6 +271,8 @@ class GeoTest(s_t_utils.SynTest):
             nodes = await core.nodes(q, opts)
             self.len(1, nodes)
             self.eq(nodes[0].get('latlong'), (11.38, 20.01))
+            nodes = await core.nodes('[ geo:place=(hehe, haha) :names=("Foo  Bar ", baz) ] -> geo:name')
+            self.eq(('baz', 'foo bar'), [n.ndef[1] for n in nodes])
 
     async def test_eq(self):
 
