@@ -32,6 +32,22 @@ class ProjModelTest(s_test.SynTest):
             tick = await core.callStorm('return($lib.projects.get($proj).tickets.add(baz))', opts=opts)
             self.nn(tick)
 
+            opts = {'user': visi.iden, 'vars': {'proj': proj, 'tick': tick}}
+            self.eq('baz', await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.name )',
+                                             opts=opts))
+            self.eq('', await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.desc )',
+                                             opts=opts))
+            self.eq(0, await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.status )',
+                                             opts=opts))
+            self.eq(0, await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.priority )',
+                                            opts=opts))
+            self.none(await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.epic )',
+                                             opts=opts))
+            self.none(await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.assignee )',
+                                             opts=opts))
+            self.none(await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.sprint )',
+                                            opts=opts))
+
             opts = {'user': visi.iden, 'vars': {'proj': proj, 'tick': tick}}
             scmd = 'return($lib.projects.get($proj).tickets.get($tick).comments.add(hello))'
             with self.raises(s_exc.AuthDeny):
@@ -84,6 +100,10 @@ class ProjModelTest(s_test.SynTest):
             await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).status = current', opts=opts)
             await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).desc = cooldesc', opts=opts)
             self.len(1, await core.nodes('proj:sprint:desc'))
+            q = 'return ( $lib.projects.get($proj).sprints.get($sprint).desc )'
+            self.eq('cooldesc', await core.callStorm(q, opts=opts))
+            q = 'return ( $lib.projects.get($proj).sprints.get($sprint).status )'
+            self.eq('current', await core.callStorm(q, opts=opts))
             await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).desc = $lib.null', opts=opts)
             self.len(0, await core.nodes('proj:sprint:desc'))
             self.len(1, await core.nodes('proj:sprint:status=current'))
@@ -106,12 +126,15 @@ class ProjModelTest(s_test.SynTest):
             self.len(0, await core.nodes('proj:ticket:assignee', opts=opts))
             await core.callStorm('$lib.projects.get($proj).tickets.get($tick).assignee = visi', opts=opts)
             self.len(1, await core.nodes('proj:ticket:assignee', opts=opts))
+            self.eq(visi.iden, await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.assignee )',
+                                                    opts=opts))
 
             with self.raises(s_exc.NoSuchUser):
                 await core.callStorm('$lib.projects.get($proj).tickets.get($tick).assignee = newp', opts=opts)
             # now as assignee visi should be able to update status
             await core.callStorm('$lib.projects.get($proj).tickets.get($tick).status = "in sprint"', opts=opts)
 
+            # Sprint setting on a ticket
             with self.raises(s_exc.AuthDeny):
                 await core.callStorm('$lib.projects.get($proj).tickets.get($tick).sprint = giter', opts=opts)
             await visi.addRule((True, ('project', 'ticket', 'set', 'sprint')), gateiden=proj)
@@ -120,6 +143,10 @@ class ProjModelTest(s_test.SynTest):
             self.len(0, await core.nodes('proj:ticket:sprint', opts=opts))
             await core.callStorm('$lib.projects.get($proj).tickets.get($tick).sprint = giter', opts=opts)
             self.len(1, await core.nodes('proj:ticket:sprint', opts=opts))
+
+            self.eq(sprint, await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.sprint )',
+                                           opts=opts))
+
             with self.raises(s_exc.NoSuchName):
                 await core.callStorm('$lib.projects.get($proj).tickets.get($tick).sprint = newp', opts=opts)
 
@@ -166,6 +193,8 @@ class ProjModelTest(s_test.SynTest):
             await core.callStorm('$lib.projects.get($proj).tickets.get($tick).epic = $lib.null', opts=aslow)
             self.len(0, await core.nodes('proj:ticket:project=$proj +:epic', opts=aslow))
             await core.callStorm('$lib.projects.get($proj).tickets.get($tick).epic = bar', opts=aslow)
+            self.eq(epic, await core.callStorm('$t=$lib.projects.get($proj).tickets.get($tick) return ( $t.epic )',
+                                               opts=aslow))
 
             with self.raises(s_exc.AuthDeny):
                 await core.callStorm('$lib.projects.get($proj).tickets.get($tick).desc = scoobie', opts=aslow)
@@ -274,6 +303,10 @@ class ProjModelTest(s_test.SynTest):
             with self.raises(s_exc.StormRuntimeError):
                 await core.callStorm(scmd, opts=opts)
 
+            scmd = '$comm=$lib.projects.get($proj).tickets.get($tick).comments.add(newp) $comm.del() return($comm.text)'
+            with self.raises(s_exc.StormRuntimeError):
+                await core.callStorm(scmd, opts=opts)
+
             self.len(0, await core.nodes('proj:comment'))
 
             scmd = 'return($lib.projects.get($proj).tickets.get($tick).comments.add(newnew))'
@@ -301,6 +334,9 @@ class ProjModelTest(s_test.SynTest):
             self.len(1, await core.nodes('yield $lib.projects.get(proj).tickets.add(tick)'))
             self.len(1, await core.nodes('yield $lib.projects.get(proj).tickets.get(tick).comments.add(comm)'))
 
+            name = await core.callStorm('$p=$lib.projects.get(proj) $p.name=newproj return ( $p.name )')
+            self.eq(name, 'newproj')
+
     async def test_model_proj_attachment(self):
 
         async with self.getTestCore() as core:
