@@ -19,6 +19,7 @@ import synapse.telepath as s_telepath
 import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.share as s_share
+import synapse.lib.certdir as s_certdir
 import synapse.lib.httpapi as s_httpapi
 import synapse.lib.version as s_version
 
@@ -387,6 +388,44 @@ class TeleTest(s_t_utils.SynTest):
             await self.asyncraises(ssl.SSLCertVerificationError,
                                    s_telepath.openurl(f'ssl://{hostname}/foo', port=addr[1]))
 
+    async def test_telepath_tls_certhash(self):
+
+        self.thisHostMustNot(platform='darwin')
+
+        foo = Foo()
+
+        with self.getTestDir() as dirn:
+
+            path = (s_common.gendir(dirn, 'dmoncerts'),)
+            certdir = s_certdir.CertDir(path=path)
+
+            async with await s_daemon.Daemon.anit(certdir=certdir) as dmon:
+
+                hostname = socket.gethostname()
+
+                certdir.genCaCert('loopy')
+                hostkey, hostcert = certdir.genHostCert(hostname, signas='loopy')
+                self.none(certdir.getHostCertHash('newp.newp.newp'))
+
+                certhash = hostcert.digest('sha256').decode().lower().replace(':', '')
+
+                host, port = await dmon.listen(f'ssl://{hostname}:0')
+                dmon.share('foo', foo)
+
+                certtext = await s_coro.executor(ssl.get_server_certificate, (hostname, port))
+                cert = certdir._loadCertByts(certtext.encode())
+
+                # host cert is *NOT* signed by a CA that client recognizes
+                with self.raises(ssl.SSLCertVerificationError):
+                    await s_telepath.openurl(f'ssl://{hostname}/foo', port=port)
+
+                with self.raises(s_exc.LinkBadCert):
+                    await s_telepath.openurl(f'ssl://{hostname}/foo', port=port, certhash='asdfasdf')
+
+                # still not, but we specify a certhash for the exact server certificate
+                async with await s_telepath.openurl(f'ssl://{hostname}/foo', port=port, certhash=certhash) as foo:
+                    self.eq('woot', await foo.echo('woot'))
+
     async def test_telepath_ssl_client_cert(self):
 
         foo = Foo()
@@ -1345,3 +1384,24 @@ class TeleTest(s_t_utils.SynTest):
             conf['version'] = 99
             s_common.yamlsave(conf, path)
             self.none(await s_telepath.loadTeleEnv(path))
+
+    async def test_telepath_default_port(self):
+        # Test default ports for dmon listening AND telepath connections.
+        async with await s_daemon.Daemon.anit() as dmon:
+            url = 'tcp://127.0.0.1/'
+            try:
+                addr, port = await dmon.listen(url)
+            except OSError as e:
+                if e.errno == 98:
+                    self.skip('Port 27492 already bound, skipping test.')
+                else:
+                    raise
+            self.eq(port, 27492)
+
+            foo = Foo()
+            dmon.share('foo', foo)
+
+            furl = 'tcp://127.0.0.1/foo'
+            async with await s_telepath.openurl(furl) as proxy:
+                self.isin('synapse.tests.test_telepath.Foo', proxy._getClasses())
+                self.eq(await proxy.echo('oh hi mark!'), 'oh hi mark!')
