@@ -1,5 +1,7 @@
 import json
+import hashlib
 
+import synapse.exc as s_exc
 import synapse.common as s_common
 
 import synapse.lib.msgpack as s_msgpack
@@ -101,3 +103,55 @@ class FeedTest(s_t_utils.SynTest):
 
             nodes = await core.nodes('test:int')
             self.len(8, nodes)
+
+    async def test_synnodes_view(self):
+
+        async with self.getTestCore() as core:
+            await self.addCreatorDeleterRoles(core)
+
+            host, port = await core.dmon.listen('tcp://127.0.0.1:0/')
+            curl = f'tcp://icanadd:secret@{host}:{port}/'
+
+            oldview = await core.callStorm('$view = $lib.view.get() return($view.iden)')
+            newview = await core.callStorm('$view = $lib.view.get() return($view.fork().iden)')
+
+            with self.getTestDir() as dirn:
+
+                mpkfp = s_common.genpath(dirn, 'podes.mpk')
+                with s_common.genfile(mpkfp) as fd:
+                    for i in range(20):
+                        pode = (('test:int', i), {})
+                        fd.write(s_msgpack.en(pode))
+
+                base = ['--cortex', curl,
+                        '--format', 'syn.nodes',
+                        '--modules', 'synapse.tests.utils.TestModule']
+
+                argv = base + ['--view', newview, mpkfp]
+
+                outp = self.getTestOutp()
+                # perms are still a thing
+                with self.raises(s_exc.AuthDeny):
+                    await s_feed.main(argv, outp=outp)
+                nodes = await core.nodes('test:int', opts={'view': newview})
+                self.len(0, nodes)
+                nodes = await core.nodes('test:int', opts={'view': oldview})
+                self.len(0, nodes)
+
+                icanadd = await core.auth.getUserByName('icanadd')
+                await icanadd.addRule((True, ('view', 'read')))
+                # now actually do the ingest
+                self.eq(await s_feed.main(argv, outp=outp), 0)
+
+                # sad path
+                outp = self.getTestOutp()
+                badview = hashlib.md5(newview.encode()).hexdigest()
+                argv = base + ['--view', badview, mpkfp]
+                with self.raises(s_exc.NoSuchView):
+                    await s_feed.main(argv, outp=outp)
+
+            nodes = await core.nodes('test:int', opts={'view': newview})
+            self.len(20, nodes)
+
+            nodes = await core.nodes('test:int', opts={'view': oldview})
+            self.len(0, nodes)
