@@ -789,6 +789,10 @@ test_schema = {
                 'description': 'Key Bool, no default.',
                 'type': 'boolean',
             },
+            'key:foo': {
+                'description': 'Foo String',
+                'type': 'string',
+            },
         },
         'type': 'object',
     }
@@ -1963,11 +1967,7 @@ class SynTest(unittest.TestCase):
 
         async with await s_lmdbslab.Slab.anit(dirn, map_size=map_size) as slab:
 
-            nexsroot = await s_nexus.NexsRoot.anit(dirn)
-            await nexsroot.startup(None)
-
-            async with await s_hive.SlabHive.anit(slab, nexsroot=nexsroot) as hive:
-                hive.onfini(nexsroot.fini)
+            async with await s_hive.SlabHive.anit(slab) as hive:
                 yield hive
 
     @contextlib.asynccontextmanager
