@@ -515,7 +515,7 @@ async def docModel(outp,
 
     return rst, rst2
 
-async def docConfdefs(ctor, reflink=':ref:`devops-cell-config`', doc_title=None):
+async def docConfdefs(ctor):
     cls = s_dyndeps.tryDynLocal(ctor)
 
     if not hasattr(cls, 'confdefs'):
@@ -524,19 +524,13 @@ async def docConfdefs(ctor, reflink=':ref:`devops-cell-config`', doc_title=None)
     rst = s_autodoc.RstHelp()
 
     clsname = cls.__name__
-    conf = cls.initCellConf()  # type: s_config.Config
-    if doc_title is None:
-        doc_title = clsname
-    rst.addHead(f'{doc_title} Configuration Options', lvl=0, link=f'.. _autodoc-{clsname.lower()}-conf:')
-    rst.addLines(f'The following are boot-time configuration options for the cell.')
 
-    rst.addLines(f'See {reflink} for details on how to set these options.')
+    conf = cls.initCellConf()  # type: s_config.Config
 
     # access raw config data
 
     # Get envar and argparse mapping
     name2envar = conf.getEnvarMapping()
-    name2cmdline = conf.getCmdlineMapping()
 
     schema = conf.json_schema.get('properties', {})
 
@@ -549,17 +543,16 @@ async def docConfdefs(ctor, reflink=':ref:`devops-cell-config`', doc_title=None)
             continue
 
         nodesc = f'No description available for ``{name}``.'
-        hname = name
-        if ':' in name:
-            hname = name.replace(':', raw_back_slash_colon)
-
-        rst.addHead(hname, lvl=1)
 
         desc = conf.get('description', nodesc)
         if not desc.endswith('.'):  # pragma: no cover
             logger.warning(f'Description for [{name}] is missing a period.')
 
+        hname = name.replace(':', raw_back_slash_colon)
         lines = []
+        lines.append(hname)
+        lines.append('~' * len(hname))
+        lines.append('')
         lines.append(desc)
 
         extended_description = conf.get('extended_description')
@@ -598,11 +591,6 @@ async def docConfdefs(ctor, reflink=':ref:`devops-cell-config`', doc_title=None)
             lines.append('Environment Variable')
             lines.append(f'    ``{envar}``\n')
 
-        cmdline = name2cmdline.get(name)
-        if cmdline:
-            lines.append('Command Line Argument')
-            lines.append(f'    ``--{cmdline}``\n')
-
         rst.addLines(*lines)
 
     return rst, clsname
@@ -761,10 +749,7 @@ async def main(argv, outp=None):
                 fd.write(rstforms.getRstText().encode())
 
     if opts.doc_conf:
-        confdocs, cname = await docConfdefs(opts.doc_conf,
-                                            reflink=opts.doc_conf_reflink,
-                                            doc_title=opts.doc_conf_title,
-                                            )
+        confdocs, cname = await docConfdefs(opts.doc_conf)
 
         if opts.savedir:
             with open(s_common.genpath(opts.savedir, f'conf_{cname.lower()}.rst'), 'wb') as fd:
@@ -807,10 +792,6 @@ def makeargparser():
                           help='Generate RST docs for the DataModel within a cortex')
     doc_type.add_argument('--doc-conf', default=None,
                           help='Generate RST docs for the Confdefs for a given Cell ctor')
-    pars.add_argument('--doc-conf-reflink', default=':ref:`devops-cell-config`',
-                      help='Reference link for how to set the cell configuration options.')
-    pars.add_argument('--doc-conf-title', default=None, type=str,
-                      help='Use a custom string for the document title.')
     doc_type.add_argument('--doc-storm', default=None,
                           help='Generate RST docs for a stormssvc implemented by a given Cell')
 
