@@ -1,5 +1,6 @@
 import sys
 import asyncio
+import logging
 import argparse
 
 import synapse.common as s_common
@@ -7,6 +8,8 @@ import synapse.common as s_common
 import synapse.lib.output as s_output
 import synapse.lib.rstorm as s_rstorm
 
+logger = logging.getLogger(__name__)
+
 prog = 'synapse.tools.rstorm'
 descr = 'An RST pre-processor that allows you to embed storm directives.'
 
@@ -23,10 +26,12 @@ async def main(argv, outp=s_output.stdout):
 
     if opts.save:
         with open(s_common.genpath(opts.save), 'w') as fd:
+            fd.truncate(0)
             [fd.write(line) for line in lines]
     else:
         for line in lines:
             outp.printf(line, addnl=False)
 
 if __name__ == '__main__':
+    s_common.setlogging(logger)
     sys.exit(asyncio.run(main(sys.argv[1:])))
